/* global describe */
/* global it */
/* global expect */

import { FastSearch, FastSearchRequest } from '../services/parsers/fastSearch';
import { PassengerType } from '../enums';
import * as moment from 'moment';

describe('fast search', () => {
	const expectResult: FastSearchRequest = {
		segments: [
			{
				departureIATA: 'MOW',
				arrivalIATA: 'LED',
				departureDate: moment('20181211', 'YYYYMMDD'),
				returnDate: null
			}
		],
		passengers: {
			ADT: 1,
			CLD: 2
		},
		commands: {}
	};

	it('should parse one way search request', () => {
		const request = '/results/MOWLED20181211ADT1CLD2';

		expect(new FastSearch(request).parse()).toEqual(expectResult);
	});

	it('should parse round trip search request', () => {
		const request = '/results/MOWLED2018121120181215ADT1CLD2';

		expectResult.segments.push({
			departureIATA: 'LED',
			arrivalIATA: 'MOW',
			departureDate: moment('20181215', 'YYYYMMDD'),
			returnDate: null
		});

		expect(new FastSearch(request).parse()).toEqual(expectResult);
	});

	it('should parse complex trip search request', () => {
		const request = '/results/MOWLED20181211LEDPAR20181213ADT1CLD2';

		expectResult.segments[1] = {
			departureIATA: 'LED',
			arrivalIATA: 'PAR',
			departureDate: moment('20181213', 'YYYYMMDD'),
			returnDate: null
		};

		expect(new FastSearch(request).parse()).toEqual(expectResult);
	});

	it('should parse commands', () => {
		const request = '/results/MOWLED20181211LEDPAR20181213ADT1CLD2-class=Business';

		expectResult.commands['class'] = {
			name: 'class',
			value: 'Business'
		};

		expect(new FastSearch(request).parse()).toEqual(expectResult);
	});
});
