import * as React from 'react';
import * as classnames from 'classnames';
import Tooltip from '@material-ui/core/Tooltip';

import CheckCircle from '@material-ui/icons/Check';
import Cancel from '@material-ui/icons/Clear';
import MonetizationOn from '@material-ui/icons/AttachMoney';

import FareFamilyFeature, { FeatureCode, FeaturePayment } from '../../schemas/FareFamilyFeature';

const paymentIcons = {
	[FeaturePayment.Free]: <CheckCircle/>,
	[FeaturePayment.Charge]: <MonetizationOn/>,
	[FeaturePayment.NotAvailable]: <Cancel/>
};

interface Props {
	features: FareFamilyFeature[];
	hideUnavailable?: boolean;
}

class Features extends React.Component<Props> {
	shouldComponentUpdate(nextProps: Props): boolean {
		return (
			this.props.features.length !== nextProps.features.length ||
			this.props.hideUnavailable !== nextProps.hideUnavailable
		);
	}

	render(): React.ReactNode {
		const { features, hideUnavailable } = this.props;
		let visibleFeatures = features;

		if (hideUnavailable) {
			visibleFeatures = features.filter(feature => feature.needToPay !== FeaturePayment.NotAvailable);
		}

		return <div className="fareFamilies-leg-segment-family__features">
			{visibleFeatures.map((feature, index) => (
				<div key={index} className="fareFamilies-leg-segment-family-feature">
					<Tooltip title={feature.description ? <span className="tooltip">{feature.description}</span> : ''} placement="top">
						<span className={classnames('fareFamilies-leg-segment-family-feature__wrapper', { 'fareFamilies-leg-segment-family-feature__wrapper_withDescription': !!feature.description })}>
							<span className={`fareFamilies-leg-segment-family-feature__icon fareFamilies-leg-segment-family-feature__icon_${feature.needToPay}`}>
								{paymentIcons[feature.needToPay]}
							</span>

							<span className="fareFamilies-leg-segment-family-feature__name">
								{feature.showTitle ? feature.title + ' — ' : ''}{feature.value}
							</span>
						</span>
					</Tooltip>
				</div>
			))}
		</div>;
	}
}

export default Features;
