import * as React from 'react';
import FlightLand from '@material-ui/icons/FlightLand';

import FlightModel from '../../models/Flight';
import { i18n } from '../../i18n';
import { BaggageInfo } from './BaggageInfo';

interface Props {
	isOpen: boolean;
	flight: FlightModel;
	isProMode?: boolean;
}

class Info extends React.Component<Props> {
	shouldComponentUpdate(nextProps: Props): boolean {
		return (
			this.props.isOpen !== nextProps.isOpen ||
			this.props.flight.id !== nextProps.flight.id
		);
	}

	renderClosed(): React.ReactNode {
		const flight: FlightModel = this.props.flight;
		const isDirect = flight.segments.length === 1;

		return <>
			{flight.stopoversInfo && <div className="flight-summary-stopovers">
				<FlightLand/>

				<div className="flight-summary-stopovers__label">
					{flight.stopoversInfo}
				</div>
			</div>}

			{!isDirect && (
				<div className="flight-summary-transfers">
					<span className="flight-summary-transfers-icon"/> {flight.transferInfo}
				</div>
			)}

			{flight.carriersMismatchLabel && <div className="flight-summary-carriersMismatch">
				{flight.carriersMismatchLabel}
			</div>}

			{!flight.baggageIsFree && (
				<div className="flight-summary__noBaggage">
					{i18n('baggage-paid-segment')}
				</div>
			)}
		</>;
	}

	renderOpened(): React.ReactNode {
		const segment = this.props.flight.firstSegment;

		return <>
			<div><strong>{segment.airline.IATA}-{segment.flightNumber}</strong>, {segment.aircraft.name}</div>

			{this.props.isProMode && <div>
				{segment.bookingClass.serviceName} ({segment.bookingClass.serviceCode})
			</div>}

			{segment.airline.IATA !== segment.operatingAirline.IATA && <div className="flight-details-segment-operatingAirline">
				{`${i18n('results-flight-operatingCompany')}: ${segment.operatingAirline.name}`}
			</div>}

			<BaggageInfo segment={segment}/>
		</>;
	}

	render(): React.ReactNode {
		return this.props.isOpen ? this.renderOpened() : this.renderClosed();
	}
}

export default Info;
