import * as React from 'react';
import Airline from '../../schemas/Airline';
import { fixImageURL } from '../../utils';
import Flight from '../../models/Flight';

const MAX_NUM_OF_LOGO_INLINE = 2;

interface Props {
	flight: Flight;
	nemoURL: string;
	isOpen: boolean;
}

class Logo extends React.Component<Props> {
	shouldComponentUpdate(nextProps: Props): boolean {
		return (
			this.props.flight.id !== nextProps.flight.id ||
			this.props.nemoURL !== nextProps.nemoURL ||
			this.props.isOpen !== nextProps.isOpen
		);
	}

	renderAsText(airlines: Airline[]): React.ReactNode {
		return <div className="flight-summary-logo__text">{airlines.map(airline => airline.name).join(', ')}</div>;
	}

	renderAsImages(airlines: Airline[]): React.ReactNode {
		return airlines.map((airline, index) => airline.logoIcon ?
			(
				<img
					key={index}
					className="flight-summary-logo__image"
					title={airline.name}
					src={fixImageURL(airline.logoIcon, this.props.nemoURL)}
				/>
			) :
			(
				<div key={index} className="flight-summary-logo__text">
					{airline.name}
				</div>
			)
		);
	}

	render(): React.ReactNode {
		const airlines: Airline[] = this.props.isOpen
			? [ this.props.flight.segments[0].airline ]
			: this.props.flight.airlinesList;

		return (
			<div className="flight-summary-logo">{(
				airlines.length > MAX_NUM_OF_LOGO_INLINE ? this.renderAsText(airlines) : this.renderAsImages(airlines)
			)}</div>
		);
	}
}

export default Logo;
