import * as React from 'react';
import { Currency, CurrencyCode } from '../enums';
import Money from '../schemas/Money';
import CurrencyRates from '../schemas/CurrencyRates';
import { convertMoney } from '../utils';

interface Props {
	price: Money;
	withPlus?: boolean;
	withMinus?: boolean;
	currency: Currency;
	rates: CurrencyRates;
}

const THOUSANDS_INDEX = 3;

class Price extends React.Component<Props> {
	shouldComponentUpdate(nextProps: Props): boolean {
		return (
			this.props.currency !== nextProps.currency ||
			this.props.rates !== nextProps.rates ||
			this.props.withPlus !== nextProps.withPlus ||
			this.props.withMinus !== nextProps.withMinus ||
			this.props.price !== nextProps.price
		);
	}

	getFormattedAmount({ amount }: Money): string {
		let tmpAmount = amount.toString(),
			fraction = '';

		const
			parts = [],
			pointIndex = tmpAmount.indexOf('.');

		if (pointIndex >= 0) {
			fraction = tmpAmount.substr(pointIndex);
			tmpAmount = tmpAmount.substr(0, pointIndex);
		}

		while(tmpAmount) {
			parts.push(tmpAmount.substr(-THOUSANDS_INDEX));
			tmpAmount = tmpAmount.substr(0, tmpAmount.length - THOUSANDS_INDEX);
		}

		parts.reverse();

		return parts.join(' ') + fraction.substr(0, 3);
	}

	render(): React.ReactNode {
		if (!this.props.price) {
			return null;
		}

		const withMinus = this.props.price.amount < 0;
		const currencySymbol = CurrencyCode[this.props.currency];

		let formattedAmount = this.getFormattedAmount(convertMoney(this.props.price, this.props.currency, this.props.rates));
		formattedAmount = formattedAmount.replace(/[+\-]/, '');

		return (
			<span className="price">
				<span className="price-amount">{this.props.withPlus && this.props.price.amount >= 0 && '+'}{withMinus && '–'} {formattedAmount}</span>
				<span className="price-currency">{currencySymbol}</span>
			</span>
		);
	}
}

export default Price;
