import * as React from 'react';
import Typography from '@material-ui/core/Typography';
// import { TransitionGroup, Transition } from 'react-transition-group';
// import { TweenMax, Power3 } from 'gsap';
import MediaQuery from 'react-responsive';

import { getCurrentLeg } from '../store/currentLeg/selectors';
import Leg from '../schemas/Leg';
import FlightsList from './FlightsList';
import { hasAnyFlights } from '../store/flightsByLegs/selectors';
import Sortings from './Sortings';
import Filters from './Filters';
import { hasAnyVisibleFlights } from '../store/selectors';
import { getLegs, isRT } from '../store/legs/selectors';
import { flightSearchIsActive } from '../store/filters/flightSearch/selectors';
import SelectedFlights from './SelectedFlights';
import { getIsLoading } from '../store/isLoading/selectors';
import { connect } from '../utils';
import { i18n } from '../i18n';
import MobileFilters from './MobileFilters';
import { ScreenMaxSize } from '../enums';

interface StateProps {
	isRT: boolean;
	isLoading: boolean;
	hasAnyFlights: boolean;
	hasAnyVisibleFlights: boolean;
	currentLeg: Leg;
	legs: Leg[];
	flightSearchActive: boolean;
}

class Results extends React.Component<StateProps> {
	renderNoFlights(): React.ReactNode {
		return !this.props.isLoading && (
			<div className="results-noResultsTitle">
				<Typography variant="headline">{i18n('results-noResultsTitle')}</Typography>
				<Typography variant="subheading">{i18n('results-noResultsSubTitle')}</Typography>
			</div>
		);
	}

	render(): React.ReactNode {
		const { currentLeg, hasAnyFlights, hasAnyVisibleFlights, isRT, flightSearchActive, legs } = this.props;
		const isMultipleLegs = legs.length > 1;

		return (
			<div className="results__inner">
				{hasAnyFlights ? <>
					{isMultipleLegs && <SelectedFlights/>}

					{/*<TransitionGroup>*/}
						{/*<Transition*/}
							{/*timeout={0}*/}
							{/*key={currentLeg ? currentLeg.id : null}*/}
							{/*onEnter={(node: HTMLElement) => {*/}
								{/*TweenMax.fromTo(node, 0.8, { opacity: 0, y: 100, ease: Power3.easeOut }, { delay: 0.25, opacity: 1, y: 0, ease: Power3.easeOut });*/}
							{/*}}*/}
						{/*>*/}
							{/*<div>*/}
								<Filters isRT={isRT} currentLeg={currentLeg} withSearch={flightSearchActive}/>

								{hasAnyVisibleFlights && <Sortings/>}

								<MediaQuery maxDeviceWidth={ScreenMaxSize.Tablet}>
									<MobileFilters/>
								</MediaQuery>

								<div className="results-flights">
									<FlightsList legId={currentLeg.id}/>
								</div>
							{/*</div>*/}
						{/*</Transition>*/}
					{/*</TransitionGroup>*/}
				</> : this.renderNoFlights()}
			</div>
		);
	}
}

export default connect<StateProps>({
	isRT: isRT,
	isLoading: getIsLoading,
	hasAnyFlights: hasAnyFlights,
	hasAnyVisibleFlights: hasAnyVisibleFlights,
	currentLeg: getCurrentLeg,
	legs: getLegs,
	flightSearchActive: flightSearchIsActive
})(Results);
