import {
	FareRules as FareRulesSchema,
	FareRulesByPassenger,
	TariffRules
} from '../schemas/FareRules';
import Fillable from './Fillable';
import { PassengerType } from '../enums';

export class FareRules extends Fillable<FareRulesSchema> implements FareRulesSchema {
	id: string;
	fareRulesByPassenger: FareRulesByPassenger[];
	tariffRules: TariffRules[][];
	passengersList: PassengerType[];
	canBeTranslated: boolean;
	isTranslated: boolean;
	manualRulesArray: string[];

	fill(fareRulesSource: FareRulesSchema): void {
		super.fill(fareRulesSource);
		this.passengersList = [];

		// If we do have any special rules, do not process rules that came from GDS.
		if (!this.manualRulesArray) {
			this.fareRulesByPassenger = this.tariffRules.map(segment => {
				const passengers: FareRulesByPassenger = {};

				segment.forEach(tariffRule => {
					if (!passengers.hasOwnProperty(tariffRule.passengerTypes[0])) {
						passengers[tariffRule.passengerTypes[0]] = [tariffRule];
					}
					else {
						passengers[tariffRule.passengerTypes[0]].push(tariffRule);
					}
				});

				return passengers;
			});

			for (const passenger in this.fareRulesByPassenger[0]) {
				if (this.fareRulesByPassenger[0].hasOwnProperty(passenger)) {
					this.passengersList.push(passenger as PassengerType);
				}
			}
		}
	}
}
