import { all, call, CallEffect, put, select, takeEvery } from 'redux-saga/effects';
import { startLoading, stopLoading } from '../../isLoading/actions';
import { getRouterLocation } from '../../selectors';
import { FastSearch } from '../../../services/parsers/fastSearch';
import airport from '../../../services/requests/airport';
import { getNemoURL } from '../../config/selectors';
import { Airport, ServiceClass } from '@nemo.travel/search-widget';
import { SearchInfo } from '@nemo.travel/search-widget';
import { PassengerType, RouteType } from '../../../enums';
import { startSearch } from '../../actions';
import { setSearchInfoFromFastSearch, PARSE_FAST_SEARCH } from '../../fastSearchInfo/actions';

interface AirportsMap {
	[IATA: string]: Airport;
}

function* worker() {
	yield put(startLoading());

	const nemoURL = yield select(getNemoURL),
		location = yield select(getRouterLocation),
		airportsMap: AirportsMap = {},
		tasks: CallEffect[] = [],
		searchInfoObject: SearchInfo = {
			segments: [],
			routeType: RouteType.OW,
			passengers: [
				{
					type: PassengerType.Adult,
					count: 1
				},
				{
					type: PassengerType.Child,
					count: 0
				},
				{
					type: PassengerType.Infant,
					count: 0
				},
				{
					type: PassengerType.InfantWithSeat,
					count: 0
				}
			],
			serviceClass: null
		};

	const fastSearch = new FastSearch(location).parse();

	fastSearch.segments.forEach(segment => {
		if (!airportsMap.hasOwnProperty(segment.departureIATA)) {
			airportsMap[segment.departureIATA] = null;

			tasks.push(call(airport, segment.departureIATA, nemoURL));
		}

		if (!airportsMap.hasOwnProperty(segment.arrivalIATA)) {
			airportsMap[segment.arrivalIATA] = null;

			tasks.push(call(airport, segment.arrivalIATA, nemoURL));
		}
	});

	const airports: Airport[] = yield all(tasks);

	airports.forEach(airport => {
		airportsMap[airport.IATA] = airport;
	});

	searchInfoObject.segments = fastSearch.segments.map(segment => {
		return {
			departure: airportsMap[segment.departureIATA],
			arrival: airportsMap[segment.arrivalIATA],
			departureDate: segment.departureDate,
			returnDate: segment.returnDate
		};
	});

	searchInfoObject.passengers.forEach(passenger => {
		if (fastSearch.passengers.hasOwnProperty(passenger.type)) {
			passenger.count = fastSearch.passengers[passenger.type];
		}
	});

	if (fastSearch.segments.length > 1) {
		if (
			fastSearch.segments.length === 2 &&
			fastSearch.segments[0].departureIATA === fastSearch.segments[1].arrivalIATA &&
			fastSearch.segments[0].arrivalIATA === fastSearch.segments[1].departureIATA
		) {
			searchInfoObject.routeType = RouteType.RT;
		}
		else {
			searchInfoObject.routeType = RouteType.CR;
		}
	}

	if (fastSearch.commands.hasOwnProperty('class')) {
		searchInfoObject.serviceClass = fastSearch.commands['class'].value as ServiceClass;
	}
	else {
		searchInfoObject.serviceClass = 'Economy' as ServiceClass;
	}

	yield put(setSearchInfoFromFastSearch(searchInfoObject));
	yield put(stopLoading());
	yield put(startSearch(searchInfoObject));
}

export default function* loadResultsFromFastSearch() {
	yield takeEvery(PARSE_FAST_SEARCH, worker);
}
